@@ -2,7 +2,7 @@
 	main.c (08.11.10)
 	Prints detailed information about exFAT volume.
 
-	Copyright (C) 2010  Andrew Nayenko
+	Copyright (C) 2011-2013  Andrew Nayenko
 
 	This program is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -76,7 +76,7 @@ static int dump_sb(const char* spec)
 	struct exfat_dev* dev;
 	struct exfat_super_block sb;
 
-	dev = exfat_open(spec, 1);
+	dev = exfat_open(spec, EXFAT_MODE_RO);
 	if (dev == NULL)
 		return 1;
 
@@ -112,7 +112,7 @@ static void dump_sectors(struct exfat* ef)
 	puts("");
 }
 
-static int dump_full(const char* spec, int used_sectors)
+static int dump_full(const char* spec, bool used_sectors)
 {
 	struct exfat ef;
 	uint32_t free_clusters;
@@ -148,8 +148,8 @@ int main(int argc, char* argv[])
 {
 	char** pp;
 	const char* spec = NULL;
-	int sb_only = 0;
-	int used_sectors = 0;
+	bool sb_only = false;
+	bool used_sectors = false;
 
 	printf("dumpexfat %u.%u.%u\n",
 			EXFAT_VERSION_MAJOR, EXFAT_VERSION_MINOR, EXFAT_VERSION_PATCH);
@@ -157,12 +157,12 @@ int main(int argc, char* argv[])
 	for (pp = argv + 1; *pp; pp++)
 	{
 		if (strcmp(*pp, "-s") == 0)
-			sb_only = 1;
+			sb_only = true;
 		else if (strcmp(*pp, "-u") == 0)
-			used_sectors = 1;
+			used_sectors = true;
 		else if (strcmp(*pp, "-v") == 0)
 		{
-			puts("Copyright (C) 2010  Andrew Nayenko");
+			puts("Copyright (C) 2011-2013  Andrew Nayenko");
 			return 0;
 		}
 		else if (spec == NULL)
