@@ -2,7 +2,7 @@
 	cbm.h (09.11.10)
 	Clusters Bitmap creation code.
 
-	Copyright (C) 2009, 2010  Andrew Nayenko
+	Copyright (C) 2011-2013  Andrew Nayenko
 
 	This program is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@
 #ifndef MKFS_CBM_H_INCLUDED
 #define MKFS_CBM_H_INCLUDED
 
-off_t cbm_alignment(void);
-off_t cbm_size(void);
-int cbm_write(struct exfat_dev* dev, off_t base);
+#include "mkexfat.h"
+
+extern const struct fs_object cbm;
 
 #endif /* ifndef MKFS_CBM_H_INCLUDED */
