@@ -2,7 +2,7 @@
 	fat.h (09.11.10)
 	File Allocation Table creation code.
 
-	Copyright (C) 2009, 2010  Andrew Nayenko
+	Copyright (C) 2011-2013  Andrew Nayenko
 
 	This program is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@
 #ifndef MKFS_FAT_H_INCLUDED
 #define MKFS_FAT_H_INCLUDED
 
-off_t fat_alignment(void);
-off_t fat_size(void);
-int fat_write(struct exfat_dev* dev, off_t base);
+#include "mkexfat.h"
+
+extern const struct fs_object fat;
 
 #endif /* ifndef MKFS_FAT_H_INCLUDED */
