@@ -2,7 +2,7 @@
 	uct.c (09.11.10)
 	Upper Case Table creation code.
 
-	Copyright (C) 2009, 2010  Andrew Nayenko
+	Copyright (C) 2011-2013  Andrew Nayenko
 
 	This program is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -18,37 +18,33 @@
 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <unistd.h>
-#include <errno.h>
-#include "mkexfat.h"
+#include "uct.h"
 #include "uctc.h"
 
-off_t uct_alignment(void)
+static off_t uct_alignment(void)
 {
-	return CLUSTER_SIZE(sb);
+	return get_cluster_size();
 }
 
-off_t uct_size(void)
+static off_t uct_size(void)
 {
 	return sizeof(upcase_table);
 }
 
-static le32_t uct_checksum(void)
-{
-	size_t i;
-	uint32_t sum = 0;
-
-	for (i = 0; i < sizeof(upcase_table); i++)
-		sum = ((sum << 31) | (sum >> 1)) + upcase_table[i];
-	return cpu_to_le32(sum);
-}
-
-int uct_write(struct exfat_dev* dev, off_t base)
+static int uct_write(struct exfat_dev* dev)
 {
 	if (exfat_write(dev, upcase_table, sizeof(upcase_table)) < 0)
-		return errno;
-	upcase_entry.checksum = uct_checksum();
-	upcase_entry.start_cluster = cpu_to_le32(OFFSET_TO_CLUSTER(base));
-	upcase_entry.size = cpu_to_le64(sizeof(upcase_table));
+	{
+		exfat_error("failed to write upcase table of %zu bytes",
+				sizeof(upcase_table));
+		return 1;
+	}
 	return 0;
 }
+
+const struct fs_object uct =
+{
+	.get_alignment = uct_alignment,
+	.get_size = uct_size,
+	.write = uct_write,
+};
