@@ -2,7 +2,7 @@
 	vbr.h (09.11.10)
 	Volume Boot Record creation code.
 
-	Copyright (C) 2009, 2010  Andrew Nayenko
+	Copyright (C) 2011-2013  Andrew Nayenko
 
 	This program is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@
 #ifndef MKFS_VBR_H_INCLUDED
 #define MKFS_VBR_H_INCLUDED
 
-off_t vbr_alignment(void);
-off_t vbr_size(void);
-int vbr_write(struct exfat_dev* dev, off_t base);
+#include "mkexfat.h"
+
+extern const struct fs_object vbr;
 
 #endif /* ifndef MKFS_VBR_H_INCLUDED */
